#!/usr/bin/env bash
# -*- coding: utf-8 -*-
# coding: utf-8
# vim: tabstop=2 expandtab shiftwidth=2 softtabstop=2
# vim: set fileencoding=utf-8
source /scripts/basic_vars
set -o nounset
set -o pipefail
set -o errexit
#
if [ "1" != "$#" ]; then exit 0; fi
#
exec 1> >(systemd-cat -p info -t app_onboard) 2>&1
set -o xtrace
#
if [ -z "${is_native_applications_enabled_in_config}" ]; then
  echo "Native applications are disabled in configuration!"
  exit 3
fi
if [ ! -f ${VERIFIED_LICENSE_FILE} ]; then
  echo "No valid license !"
  exit 4
fi
if [ -z "${is_native_app_enabled_in_license}" ]; then
  echo "Native applications not allowed by a valid license !";
  exit 5
fi
#
FAKE_APPNAME=${1}
APPNAME=""
APPDIR=""
CONFIG=""
USER_DATA_FILE=""
AUTOSTART="false"
APPJSON=""
#
sudo rm -rf /var/tmp/onboard
sudo mkdir -p /var/tmp/onboard
sudo tar xzf /home/admin/user_files/${FAKE_APPNAME}.tar.gz -C /var/tmp/onboard
#
APPJSON=$(find /var/tmp/onboard -name application.json)
APPNAME=$(jq .name ${APPJSON} | tr -d '"' |tr '[:upper:]' '[:lower:]')
#
if [ -n "$(echo ${APPNAME} | grep --ignore-case clavister)" ] \
   && [ -z "${is_native_app_clavister_enabled_in_license}" ]; then
  echo "Native application Clavister not allowed by a valid license !"
  exit 5
elif [ -n "$(echo ${APPNAME} | grep --ignore-case mikrotik)" ] \
     && [ -z "${is_native_app_mikrotik_enabled_in_license}" ]; then
  echo "Native application MikroTik not allowed by a valid license !"
  exit 5
fi
#
FAKEDIR=$(dirname ${APPJSON})
# can not move - cause system reboot ! and libs
cd ${FAKEDIR}/..
sudo tar cf /var/tmp/${APPNAME}.tar *
sudo mkdir -p /root/apps/${APPNAME}
cd /tmp
sudo tar xf /var/tmp/${APPNAME}.tar -C /root/apps/${APPNAME}
sudo rm -rf /var/tmp/onboard /var/tmp/${APPNAME}.tar
APPDIR=/root/apps/${APPNAME}
sudo cp -f /root/apps/${APPNAME}/${APPNAME}.service /lib/systemd/system
sudo chmod 644 /lib/systemd/system/${APPNAME}.service
sudo systemctl daemon-reload
#
if [ -f ${APPDIR}/config/application.json ]; then
  CONFIG=$(jq .config ${APPDIR}/config/application.json | tr -d '"')
  if [ -f ${APPDIR}/config/${CONFIG} ]; then
    USER_DATA_FILE=$(jq .general.user_data_file ${APPDIR}/config/${CONFIG} | tr -d '"' )
    if [ -f ${APPDIR}/config/${USER_DATA_FILE} ]; then
      sudo cp -f ${APPDIR}/config/${USER_DATA_FILE} /root/apps/${APPNAME}/sgwroot/core.cfg
    fi
    AUTOSTART=$(jq .general.autostart ${APPDIR}/config/${CONFIG} | tr -d '"')
    if [ "true" = "${AUTOSTART}" ]; then
      sudo systemctl enable ${APPNAME}.service 2>/dev/null
    fi
    ROUTING=$(jq .general.routing ${APPDIR}/config/${CONFIG} | tr -d '"')
    if [ "true" = "${ROUTING}" ]; then
      sysctl -w net.ipv4.ip_forward=1 || true
      sed -i '/^net.ipv4.ip_forward/d' /etc/sysctl.conf
      sed -i '${x;/^$/{s//net.ipv4.ip_forward=1/;H};x}' /etc/sysctl.conf
    fi
  fi
fi
# if somehow exists in the tar
if [ -f ${APPDIR}/successful_initialized ]; then
  rm -f ${APPDIR}/successful_initialized
fi
exit 0
