#!/usr/bin/env bash
# -*- coding: utf-8 -*-
# coding: utf-8
# vim: tabstop=2 expandtab shiftwidth=2 softtabstop=2
# vim: set fileencoding=utf-8
source /scripts/basic_vars
set -o nounset
set -o pipefail
set -o errexit
#
if [ "1" != "$#" ]; then exit 0; fi
#
if [ -z "${is_native_applications_enabled_in_config}" ]; then
  echo "Native applications are disabled in configuration!"
  exit 3
fi
if [ ! -f ${VERIFIED_LICENSE_FILE} ]; then
  echo "No valid license !"
  exit 4
fi
if [ -z "${is_native_app_enabled_in_license}" ]; then
  echo "Native applications not allowed by a valid license !";
  exit 5
fi
#
APPNAME_MIXED_LETTERS=${1}
APPNAME=$(echo -n "${APPNAME_MIXED_LETTERS}" | tr '[:upper:]' '[:lower:]')
APPDIR=/root/apps/${APPNAME}
APPJSON=/root/apps/${APPNAME}/config/application.json
ONDEMAND="false"
exec 1> >(systemd-cat -p info -t app_reset) 2>&1
set -o xtrace
#
if [ -n "$(echo ${APPNAME} | grep --ignore-case clavister)" ] \
   && [ -z "${is_native_app_clavister_enabled_in_license}" ]; then
  echo "Native application Clavister not allowed by a valid license !"
  exit 5
elif [ -n "$(echo ${APPNAME} | grep --ignore-case mikrotik)" ] \
     && [ -z "${is_native_app_mikrotik_enabled_in_license}" ]; then
  echo "Native application MikroTik not allowed by a valid license !"
  exit 5
fi
#
sudo systemctl stop ${APPNAME}.service
sudo rm -f /root/apps/${APPNAME}/successful_initialized /root/apps/${APPNAME}/${APPNAME}_ifs_setup
#
exit 0
