#!/usr/bin/env bash
# -*- coding: utf-8 -*-
# coding: utf-8
# vim: tabstop=2 expandtab shiftwidth=2 softtabstop=2
# vim: set fileencoding=utf-8
source /scripts/basic_vars
set -o nounset
set -o pipefail
set -o errexit
#
if [ "1" != "$#" ]; then exit 0; fi
#
exec 1> >(systemd-cat -p info -t app_retrieveconfigs) 2>&1
set -o xtrace
#
if [ -z "${is_native_applications_enabled_in_config}" ]; then
  echo "Native applications are disabled in configuration!"
  exit 3
fi
if [ ! -f ${VERIFIED_LICENSE_FILE} ]; then
  echo "No valid license !"
  exit 4
fi
if [ -z "${is_native_app_enabled_in_license}" ]; then
  echo "Native applications not allowed by a valid license !";
  exit 5
fi
#
APPNAME=${1}
#
if [ -n "$(echo ${APPNAME} | grep --ignore-case clavister)" ] \
   && [ -z "${is_native_app_clavister_enabled_in_license}" ]; then
  echo "Native application Clavister not allowed by a valid license !"
  exit 5
elif [ -n "$(echo ${APPNAME} | grep --ignore-case mikrotik)" ] \
     && [ -z "${is_native_app_mikrotik_enabled_in_license}" ]; then
  echo "Native application MikroTik not allowed by a valid license !"
  exit 5
fi
#
APPJSON=/root/apps/${APPNAME}/config/application.json
shopt -s nocasematch
#
TMPDIR=$(mktemp -d)
if [ -f ${APPJSON} ]; then
  cp -f ${APPJSON} ${TMPDIR}
fi
APPTEMPLATE=$(jq '.config' ${APPJSON} | tr -d '"')
if [ -d /root/apps/${APPNAME}/config ]; then
  cp -f /root/apps/${APPNAME}/config/* ${TMPDIR}
fi
USER_DATA_FILE=$(jq '."user-data-file"' /root/apps/${APPNAME}/config/${APPTEMPLATE} | tr -d '"' )
if [ -f /root/apps/${APPNAME}/${USER_DATA_FILE} ]; then
  cp -f /root/apps/${APPNAME}/${USER_DATA_FILE} ${TMPDIR}
fi
if [ -f /root/apps/${APPNAME}/sgwroot/license.lic ]; then
  cp -f /root/apps/${APPNAME}/sgwroot/license.lic ${TMPDIR}
fi
cd ${TMPDIR}
tar czf /home/admin/user_files/${APPNAME}_configs.tar.gz *
cd /tmp
rm -rf ${TMPDIR}
exit 0
