#!/usr/bin/env python3
# -*- coding: utf-8 -*-

from enum import Flag
import os
import netifaces  as net

BIND_INTERFACE_FILE = '/kubernetes/bind-interface-file'
K8S_ENABLED_FILE = '/config/k8s-enabled'
CENTRAL_CONTROLLER = '/config/central-box'
K8S_SINGLE_MACHINE = '/config/k8s-single-machine'
KUBELET_CONFIG = '/etc/systemd/system/kubelet.service.d/10-kubeadm.conf'
K8S_INIT_RUNNING_CMD = 'systemctl is-active nfvtime-kubernetes-init.service >/dev/null'

class ClusterValidator(object):

    @staticmethod
    def get_bind_interface():
        try:
            with open(BIND_INTERFACE_FILE, 'r') as file:
                iface = file.read()
                return iface
        except FileNotFoundError:
            return None
        except Exception as e:
            return None

    @staticmethod
    def get_ip(interface):
        # TODO:  ipv6
        try:
            return net.ifaddresses(interface)[net.AF_INET][0]['addr']
        except Exception:
            return ''


    @staticmethod
    def get_kubeadm_ip():
        with open(KUBELET_CONFIG) as f:
            f.seek(0)
            lines = f.readlines()
            for line in lines:
                for flag in line.split():
                    if "--node-ip" in flag:
                        try:
                            return flag.split("--node-ip=")[1][:-1]
                        except Exception:
                            continue

        return ''

    @staticmethod
    def is_k8s_controller():
        return os.path.isfile(CENTRAL_CONTROLLER)

    @staticmethod
    def is_k8s_single_machine():
        return os.path.isfile(K8S_SINGLE_MACHINE)

    @staticmethod
    def is_control_plane():
        return __class__.is_k8s_controller() or __class__.is_k8s_single_machine()

    @staticmethod
    def is_k8s_init_running():
        return os.system(K8S_INIT_RUNNING_CMD) == 0

    @staticmethod
    def is_k8s_ip_matching():
        c = __class__
        kubeadm_ip = c.get_kubeadm_ip()
        bind_iface_ip = c.get_ip(c.get_bind_interface())
        if kubeadm_ip and bind_iface_ip:
            return kubeadm_ip == bind_iface_ip
        
        return False

    @staticmethod
    def is_cluster_creating():
        c = __class__
        if c.is_control_plane() and c.is_k8s_ip_matching() and \
           c.is_k8s_init_running():
            return True
        
        return False
    